@@ -39,8 +39,6 @@
 
 YAZ_BEGIN_CDECL
 
-#define COMSTACK_DEFAULT_TIMEOUT -1  /* not used yet */
-
 struct comstack;
 typedef struct comstack *COMSTACK;
 typedef COMSTACK (*CS_TYPE)(int s, int flags, int protocol, void *vp);
@@ -50,7 +48,6 @@ struct comstack
     CS_TYPE type;
     int cerrno;     /* current error code of this stack */
     int iofile;    /* UNIX file descriptor for iochannel */
-    int timeout;   /* how long to wait for trailing blocks (ignored for now) */
     void *cprivate;/* state info for lower stack */
     int max_recv_bytes;      /* max size of incoming package */
     int state;     /* current state */
@@ -134,8 +131,6 @@ YAZ_EXPORT int cs_set_ssl_ctx(COMSTACK cs, void *ctx);
 YAZ_EXPORT int cs_set_ssl_certificate_file(COMSTACK cs, const char *fname);
 YAZ_EXPORT int cs_get_peer_certificate_x509(COMSTACK cs, char **buf, int *len);
 YAZ_EXPORT void cs_set_max_recv_bytes(COMSTACK cs, int max_recv_bytes);
-YAZ_EXPORT int completeWAIS(const char *buf, int len);
-
 YAZ_EXPORT void cs_print_session_info(COMSTACK cs);
 
 /*
@@ -152,10 +147,6 @@ YAZ_EXPORT void cs_print_session_info(COMSTACK cs);
 #define CSBUFSIZE  7
 #define CSLASTERROR CSBUFSIZE  /* must be the value of last CS error */
 
-/* backwards compatibility */
-#define CS_SR     PROTO_SR
-#define CS_Z3950  PROTO_Z3950
-
 #define CS_FLAGS_BLOCKING 1
 #define CS_FLAGS_NUMERICHOST 2
 
